# Plugins

Plugins extend the functionality of Mousetrap.  To use a plugin just include the plugin after mousetrap.

```html
<script src="mousetrap.js"></script>
<script src="mousetrap-record.js"></script>
```

## Bind dictionary

Allows you to make multiple bindings in a single ``Mousetrap.bind`` call.

## Global bind

Allows you to set global bindings that work even inside of input fields.

## Pause/unpause

Allows you to temporarily prevent Mousetrap events from firing.

## Record

Allows you to capture a keyboard shortcut or sequence defined by a user.
